/*
 * Copyright (c) 2011 Apple Inc. All rights reserved.
 *
 * @APPLE_LICENSE_HEADER_START@
 * 
 * This file contains Original Code and/or Modifications of Original Code
 * as defined in and that are subject to the Apple Public Source License
 * Version 2.0 (the 'License'). You may not use this file except in
 * compliance with the License. Please obtain a copy of the License at
 * http://www.opensource.apple.com/apsl/ and read it before using this
 * file.
 * 
 * The Original Code and all software distributed under the License are
 * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
 * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
 * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
 * Please see the License for the specific language governing rights and
 * limitations under the License.
 * 
 * @APPLE_LICENSE_HEADER_END@
 */

#include <sys/kdebug.h>

/*
 * Kernel Debug subclass for FAT is 0xF.
 *
 * That means that our codes are of the form 0x030Fxxxx.
 */
#define MSDOSFS_CODE(code)  KDBG_CODE(DBG_FSYSTEM, 0xF, code)

enum {
    MSDOSFS_VFS_MOUNT		=   MSDOSFS_CODE(0),	/* 0x030f0000 */
    MSDOSFS_VFS_START		=   MSDOSFS_CODE(1),	/* 0x030f0004 */
    MSDOSFS_VFS_UNMOUNT		=   MSDOSFS_CODE(2),	/* 0x030f0008 */
    MSDOSFS_VFS_ROOT		=   MSDOSFS_CODE(3),	/* 0x030f000c */
    MSDOSFS_VFS_GETATTR		=   MSDOSFS_CODE(4),	/* 0x030f0010 */
    MSDOSFS_VFS_SYNC		=   MSDOSFS_CODE(5),	/* 0x030f0014 */
    MSDOSFS_VFS_INIT		=   MSDOSFS_CODE(6),	/* 0x030f0018 */
    MSDOSFS_VFS_SYSCTL		=   MSDOSFS_CODE(7),	/* 0x030f001c */
    MSDOSFS_VFS_SETATTR		=   MSDOSFS_CODE(8),	/* 0x030f0020 */
    MSDOSFS_VFS_STATFS		=   MSDOSFS_CODE(9),	/* 0x030f0024 */
    
    MSDOSFS_VNOP_LOOKUP		=   MSDOSFS_CODE(16),	/* 0x030f0040 */
    MSDOSFS_VNOP_CREATE		=   MSDOSFS_CODE(17),	/* 0x030f0044 */
    MSDOSFS_VNOP_MKNOD		=   MSDOSFS_CODE(18),	/* 0x030f0048 */
    MSDOSFS_VNOP_OPEN		=   MSDOSFS_CODE(19),	/* 0x030f004c */
    MSDOSFS_VNOP_CLOSE		=   MSDOSFS_CODE(20),	/* 0x030f0050 */
    MSDOSFS_VNOP_GETATTR	=   MSDOSFS_CODE(21),	/* 0x030f0054 */
    MSDOSFS_VNOP_SETATTR	=   MSDOSFS_CODE(22),	/* 0x030f0058 */
    MSDOSFS_VNOP_READ		=   MSDOSFS_CODE(23),	/* 0x030f005c */
    MSDOSFS_VNOP_WRITE		=   MSDOSFS_CODE(24),	/* 0x030f0060 */
    MSDOSFS_VNOP_FSYNC		=   MSDOSFS_CODE(25),	/* 0x030f0064 */
    MSDOSFS_VNOP_REMOVE		=   MSDOSFS_CODE(26),	/* 0x030f0068 */
    MSDOSFS_VNOP_RENAME		=   MSDOSFS_CODE(27),	/* 0x030f006c */
    MSDOSFS_VNOP_MKDIR		=   MSDOSFS_CODE(28),	/* 0x030f0070 */
    MSDOSFS_VNOP_RMDIR		=   MSDOSFS_CODE(29),	/* 0x030f0074 */
    MSDOSFS_VNOP_READDIR	=   MSDOSFS_CODE(30),	/* 0x030f0078 */
    MSDOSFS_VNOP_INACTIVE	=   MSDOSFS_CODE(31),	/* 0x030f007c */
    MSDOSFS_VNOP_RECLAIM	=   MSDOSFS_CODE(32),	/* 0x030f0080 */
    MSDOSFS_VNOP_PATHCONF	=   MSDOSFS_CODE(33),	/* 0x030f0084 */
    MSDOSFS_VNOP_PAGEIN		=   MSDOSFS_CODE(34),	/* 0x030f0088 */
    MSDOSFS_VNOP_PAGEOUT	=   MSDOSFS_CODE(35),	/* 0x030f008c */
    MSDOSFS_VNOP_BLKTOOFF	=   MSDOSFS_CODE(36),	/* 0x030f0090 */
    MSDOSFS_VNOP_OFFTOBLK	=   MSDOSFS_CODE(37),	/* 0x030f0094 */
    MSDOSFS_VNOP_BLOCKMAP	=   MSDOSFS_CODE(38),	/* 0x030f0098 */
    MSDOSFS_VNOP_STRATEGY	=   MSDOSFS_CODE(39),	/* 0x030f009c */
    MSDOSFS_VNOP_SYMLINK	=   MSDOSFS_CODE(40),	/* 0x030f00a0 */
    MSDOSFS_VNOP_READLINK	=   MSDOSFS_CODE(41),	/* 0x030f00a4 */
    MSDOSFS_VNOP_IOCTL		=   MSDOSFS_CODE(42),	/* 0x030f00a8 */
    
    MSDOSFS_UPDATE_FSINFO	=   MSDOSFS_CODE(64),	/* 0x030f0100 */
    MSDOSFS_FAT_CACHE_FLUSH	=   MSDOSFS_CODE(65),	/* 0x030f0104 */
    MSDOSFS_FAT_MAP		=   MSDOSFS_CODE(66),	/* 0x030f0108 */
    MSDOSFS_META_FLUSH_INTERNAL	=   MSDOSFS_CODE(67),	/* 0x030f010c */
    MSDOSFS_META_FLUSH		=   MSDOSFS_CODE(68),	/* 0x030f0110 */
    MSDOSFS_META_SYNC_CALLBACK	=   MSDOSFS_CODE(69),	/* 0x030f0114 */
    MSDOSFS_PCBMAP_INTERNAL	=   MSDOSFS_CODE(70),	/* 0x030f0118 */
    MSDOSFS_PCBMAP		=   MSDOSFS_CODE(71),	/* 0x030f011c */
    /* 0x030f0120 was MSDOSFS_CLUSTERFREE_INTERNAL */
    /* 0x030f0124 was MSDOSFS_CLUSTERFREE */
    MSDOSFS_FATENTRY_INTERNAL	=   MSDOSFS_CODE(74),	/* 0x030f0128 */
    MSDOSFS_FATENTRY		=   MSDOSFS_CODE(75),	/* 0x030f012c */
    MSDOSFS_FATCHAIN		=   MSDOSFS_CODE(76),	/* 0x030f0130 */
    MSDOSFS_CHAINLENGTH		=   MSDOSFS_CODE(77),	/* 0x030f0134 */
    MSDOSFS_CHAINALLOC		=   MSDOSFS_CODE(78),	/* 0x030f0138 */
    MSDOSFS_CLUSTERALLOC_INTERNAL=   MSDOSFS_CODE(79),	/* 0x030f013c */
    MSDOSFS_CLUSTERALLOC	=   MSDOSFS_CODE(80),	/* 0x030f0140 */
    MSDOSFS_FREECLUSTERCHAIN	=   MSDOSFS_CODE(81),	/* 0x030f0144 */
    MSDOSFS_COUNT_FREE_CLUSTERS	=   MSDOSFS_CODE(82),	/* 0x030f0148 */
    MSDOSFS_EXTENDFILE		=   MSDOSFS_CODE(83),	/* 0x030f014c */
    MSDOSFS_MARKVOLDIRTY	=   MSDOSFS_CODE(84),	/* 0x030f0150 */
    MSDOSFS_FAT_FSYNC		=   MSDOSFS_CODE(85),	/* 0x030f0154 */
    MSDOSFS_FIND_FREE_EXTENTS	=   MSDOSFS_CODE(86),	/* 0x030f0158 */
    MSDOSFS_FIND_NEXT_FREE	=   MSDOSFS_CODE(87),	/* 0x030f015C */
    MSDOSFS_LOOKUP_NAME		=   MSDOSFS_CODE(88),	/* 0x030f0160 */
    MSDOSFS_FINDSLOTS		=   MSDOSFS_CODE(89),	/* 0x030f0164 */
    MSDOSFS_UNIQDOSNAME		=   MSDOSFS_CODE(90),	/* 0x030f0168 */
    MSDOSFS_CREATEDE		=   MSDOSFS_CODE(91),	/* 0x030f016C */
    MSDOSFS_FREESPACE		=   MSDOSFS_CODE(92),	/* 0x030f0170 */
};